==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkMNITagPointReader.java <==
// java wrapper for vtkMNITagPointReader object
//

package vtk;
import vtk.*;

public class vtkMNITagPointReader extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native String GetFileExtensions_4();
  public String GetFileExtensions()
    { return GetFileExtensions_4(); }

  private native String GetDescriptiveName_5();
  public String GetDescriptiveName()
    { return GetDescriptiveName_5(); }

  private native int CanReadFile_6(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_6(id0); }

  private native int GetNumberOfVolumes_7();
  public int GetNumberOfVolumes()
    { return GetNumberOfVolumes_7(); }

  private native long GetPoints_8(int id0);
  public vtkPoints GetPoints(int id0) {
    long temp = GetPoints_8(id0);

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetPoints_9();
  public vtkPoints GetPoints() {
    long temp = GetPoints_9();

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetLabelText_10();
  public vtkStringArray GetLabelText() {
    long temp = GetLabelText_10();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetWeights_11();
  public vtkDoubleArray GetWeights() {
    long temp = GetWeights_11();

    if (temp == 0) return null;
    return (vtkDoubleArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetStructureIds_12();
  public vtkIntArray GetStructureIds() {
    long temp = GetStructureIds_12();

    if (temp == 0) return null;
    return (vtkIntArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetPatientIds_13();
  public vtkIntArray GetPatientIds() {
    long temp = GetPatientIds_13();

    if (temp == 0) return null;
    return (vtkIntArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native String GetComments_14();
  public String GetComments()
    { return GetComments_14(); }

  public vtkMNITagPointReader() { super(); }

  public vtkMNITagPointReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkMNITagPointReader.java <==
// java wrapper for vtkMNITagPointReader object
//

package vtk;
import vtk.*;

public class vtkMNITagPointReader extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native String GetFileExtensions_4();
  public String GetFileExtensions()
    { return GetFileExtensions_4(); }

  private native String GetDescriptiveName_5();
  public String GetDescriptiveName()
    { return GetDescriptiveName_5(); }

  private native int CanReadFile_6(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_6(id0); }

  private native int GetNumberOfVolumes_7();
  public int GetNumberOfVolumes()
    { return GetNumberOfVolumes_7(); }

  private native long GetPoints_8(int id0);
  public vtkPoints GetPoints(int id0) {
    long temp = GetPoints_8(id0);

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPoints_9();
  public vtkPoints GetPoints() {
    long temp = GetPoints_9();

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLabelText_10();
  public vtkStringArray GetLabelText() {
    long temp = GetLabelText_10();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetWeights_11();
  public vtkDoubleArray GetWeights() {
    long temp = GetWeights_11();

    if (temp == 0) return null;
    return (vtkDoubleArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructureIds_12();
  public vtkIntArray GetStructureIds() {
    long temp = GetStructureIds_12();

    if (temp == 0) return null;
    return (vtkIntArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPatientIds_13();
  public vtkIntArray GetPatientIds() {
    long temp = GetPatientIds_13();

    if (temp == 0) return null;
    return (vtkIntArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetComments_14();
  public String GetComments()
    { return GetComments_14(); }

  public vtkMNITagPointReader() { super(); }

  public vtkMNITagPointReader(long id) { super(id); }
  public native long   VTKInit();

}
